==> plasma-framework-5.66.0.tar.xz: plasma-framework-5.66.0/src/desktoptheme/breeze-dark/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze Dark
Name[ar]=نسيم داكن
Name[ca]=Brisa fosca
Name[ca@valencia]=Brisa fosca
Name[cs]=Breeze Tmavé
Name[da]=Breeze Dark
Name[de]=Breeze-Dunkel
Name[en_GB]=Breeze Dark
Name[es]=Brisa oscuro
Name[et]=Breeze tume
Name[eu]=Breeze iluna
Name[fi]=Breeze Dark
Name[fr]=Breeze sombre
Name[gd]=Dorch-oiteag
Name[gl]=Breeze escuro
Name[hu]=Breeze Dark
Name[ia]=Brisa obscure
Name[id]=Breeze Gelap
Name[it]=Brezza scuro
Name[ko]=어두운 Breeze
Name[lt]=Breeze tamsus
Name[lv]=Tumšā brīze
Name[nb]=Mørk bris
Name[nds]=Breeze düüster
Name[nl]=Breeze Dark
Name[nn]=Breeze mørk
Name[pl]=Ciemna bryza
Name[pt]=Brisa Escura
Name[pt_BR]=Breeze Dark
Name[ru]=Breeze, тёмный вариант
Name[sk]=Vánok Tmavý
Name[sl]=Sapica (temna)
Name[sr]=Поветарац тамни
Name[sr@ijekavian]=Поветарац тамни
Name[sr@ijekavianlatin]=Povetarac tamni
Name[sr@latin]=Povetarac tamni
Name[sv]=Breeze mörk
Name[tg]=Насими торик
Name[tr]=Esintili Koyu
Name[uk]=Темна Breeze
Name[x-test]=xxBreeze Darkxx
Name[zh_CN]=暗色微风
Name[zh_TW]=Breeze Dark
Comment=Breeze Dark by the KDE VDG
Comment[ca]=Brisa fosca pel VDG del KDE
Comment[ca@valencia]=Brisa fosca pel VDG del KDE
Comment[cs]=Breeze Dark od KDE VDG
Comment[da]=Breeze Dark af KDE VDG
Comment[de]=Breeze-Dunkel von der KDE VDG
Comment[en_GB]=Breeze Dark by the KDE VDG
Comment[es]=Brisa oscuro por KDE VDG
Comment[et]=Breeze tume KDE VDG-lt
Comment[eu]=Breeze iluna, KDE VDGk egina
Comment[fi]=Breeze Dark KDE VDG:ltä
Comment[fr]=Breeze sombre, par KDE VDG
Comment[gl]=Breeze escuro de KDE VDG
Comment[hu]=Breeze Dark a KDE VDG-től
Comment[ia]=Breeze Dark (Brisa Obscure) per le KDE VDG
Comment[id]=Breeze Gelap oleh KDE VDG
Comment[it]=Brezza scuro del KDE VDG
Comment[ko]=KDE VDG에서 만든 어두운 Breeze
Comment[nl]=Breeze Dark door de KDE VDG
Comment[nn]=Breeze mørk frå KDE VDG
Comment[pl]=Ciemna bryza autorstwa KDE VDG
Comment[pt]=Brisa Escuro da VDG do KDE
Comment[pt_BR]=Breeze Dark pelo KDE VDG
Comment[ru]=Тёмный вариант Breeze от KDE VDG
Comment[sk]=Vánok Tmavý od KDE VDG
Comment[sv]=Breeze mörk av KDE:s visuella designgrupp
Comment[tg]=Насими торик аз KDE VDG
Comment[uk]=Темна Breeze, автори — KDE VDG
Comment[x-test]=xxBreeze Dark by the KDE VDGxx
Comment[zh_CN]=暗色微风，由 KDE VDG 创作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze Dark


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=breeze-dark
X-KDE-PluginInfo-Version=@KF5_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.2
intensity=0.4
saturation=1.7

==> plasma-framework-5.67.0.tar.xz: plasma-framework-5.67.0/src/desktoptheme/breeze-dark/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze Dark
Name[ar]=نسيم داكن
Name[ca]=Brisa fosca
Name[ca@valencia]=Brisa fosca
Name[cs]=Breeze Tmavé
Name[da]=Breeze Dark
Name[de]=Breeze-Dunkel
Name[en_GB]=Breeze Dark
Name[es]=Brisa oscuro
Name[et]=Breeze tume
Name[eu]=Breeze iluna
Name[fi]=Breeze Dark
Name[fr]=Breeze sombre
Name[gd]=Dorch-oiteag
Name[gl]=Breeze escuro
Name[hu]=Breeze Dark
Name[ia]=Brisa obscure
Name[id]=Breeze Gelap
Name[it]=Brezza scuro
Name[ko]=어두운 Breeze
Name[lt]=Breeze tamsus
Name[lv]=Tumšā brīze
Name[nb]=Mørk bris
Name[nds]=Breeze düüster
Name[nl]=Breeze Dark
Name[nn]=Breeze mørk
Name[pl]=Ciemna bryza
Name[pt]=Brisa Escura
Name[pt_BR]=Breeze Dark
Name[ru]=Breeze, тёмный вариант
Name[sk]=Vánok Tmavý
Name[sl]=Sapica (temna)
Name[sr]=Поветарац тамни
Name[sr@ijekavian]=Поветарац тамни
Name[sr@ijekavianlatin]=Povetarac tamni
Name[sr@latin]=Povetarac tamni
Name[sv]=Breeze mörk
Name[tg]=Насими торик
Name[tr]=Esintili Koyu
Name[uk]=Темна Breeze
Name[x-test]=xxBreeze Darkxx
Name[zh_CN]=暗色微风
Name[zh_TW]=Breeze Dark
Comment=Breeze Dark by the KDE VDG
Comment[ca]=Brisa fosca, creat pel VDG del KDE
Comment[ca@valencia]=Brisa fosca pel VDG del KDE
Comment[cs]=Breeze Dark od KDE VDG
Comment[da]=Breeze Dark af KDE VDG
Comment[de]=Breeze-Dunkel von der KDE VDG
Comment[en_GB]=Breeze Dark by the KDE VDG
Comment[es]=Brisa oscuro por KDE VDG
Comment[et]=Breeze tume KDE VDG-lt
Comment[eu]=Breeze iluna, KDE VDGk egina
Comment[fi]=Breeze Dark KDE VDG:ltä
Comment[fr]=Breeze sombre, par KDE VDG
Comment[gl]=Breeze escuro de KDE VDG
Comment[hu]=Breeze Dark a KDE VDG-től
Comment[ia]=Breeze Dark (Brisa Obscure) per le KDE VDG
Comment[id]=Breeze Gelap oleh KDE VDG
Comment[it]=Brezza scuro del KDE VDG
Comment[ko]=KDE VDG에서 만든 어두운 Breeze
Comment[nl]=Breeze Dark door de KDE VDG
Comment[nn]=Breeze mørk frå KDE VDG
Comment[pl]=Ciemna bryza autorstwa KDE VDG
Comment[pt]=Brisa Escuro da VDG do KDE
Comment[pt_BR]=Breeze Dark pelo KDE VDG
Comment[ru]=Тёмный вариант Breeze от KDE VDG
Comment[sk]=Vánok Tmavý od KDE VDG
Comment[sv]=Breeze mörk av KDE:s visuella designgrupp
Comment[tg]=Насими торик аз KDE VDG
Comment[uk]=Темна Breeze, автори — KDE VDG
Comment[x-test]=xxBreeze Dark by the KDE VDGxx
Comment[zh_CN]=暗色微风，由 KDE VDG 创作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze Dark


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=breeze-dark
X-KDE-PluginInfo-Version=@KF5_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.2
intensity=0.4
saturation=1.7
